@@ -1,7 +1,7 @@
-#' Get macro area by languoid
+#' Get macro area by language
 #'
-#' Takes any vector of languoids and return macro area.
-#' @param x character vector of the languoids (can be written in lower case)
+#' Takes any vector of languages and return macro area.
+#' @param x character vector of the languages (can be written in lower case)
 #' @param glottolog.source A character vector that define which glottolog database is used: 'original' or 'modified' (by default)
 #' @author George Moroz <agricolamz@gmail.com>
 #' @seealso \code{\link{aff.lang}}, \code{\link{country.lang}}, \code{\link{iso.lang}}, \code{\link{lat.lang}}, \code{\link{long.lang}}
@@ -11,11 +11,12 @@
 #' @export
 
 area.lang <- function(x, glottolog.source = "modified") {
-    ifelse(grepl(glottolog.source, "original"), glottolog <- lingtypology::glottolog.original, 
+    if(typeof(x) == "list"){x <- unlist(x)}
+    ifelse(grepl(glottolog.source, "original"), glottolog <- lingtypology::glottolog.original,
         glottolog <- lingtypology::glottolog.modified)
     vapply(x, function(y) {
-        ifelse(is.glottolog(y, response = TRUE, glottolog.source = glottolog.source) == 
-            TRUE, glottolog[tolower(glottolog$lang) == tolower(y), ]$macro_area, 
+        ifelse(is.glottolog(y, response = TRUE, glottolog.source = glottolog.source) ==
+            TRUE, glottolog[tolower(glottolog$language) %in% tolower(y), ]$area,
             NA_character_)
     }, character(1))
 }
