@@ -1,6 +1,6 @@
-#' Get languoid by ISO 639--3 code
+#' Get language by ISO 639--3 code
 #'
-#' Takes any vector of ISO codes and return languoids.
+#' Takes any vector of ISO codes and return languages.
 #' @param x A character vector of the ISO codes.
 #' @param glottolog.source A character vector that define which glottolog database is used: 'original' or 'modified' (by default)
 #' @author George Moroz <agricolamz@gmail.com>
@@ -11,10 +11,11 @@
 #' @export
 
 lang.iso <- function(x, glottolog.source = "modified") {
-    ifelse(grepl(glottolog.source, "original"), glottolog <- lingtypology::glottolog.original, 
+    if(typeof(x) == "list"){x <- unlist(x)}
+    ifelse(grepl(glottolog.source, "original"), glottolog <- lingtypology::glottolog.original,
         glottolog <- lingtypology::glottolog.modified)
     vapply(x, function(y) {
-        ifelse(y %in% glottolog$iso, glottolog[tolower(glottolog$iso) %in% tolower(y), 
-            ]$languoid, NA_character_)
+        ifelse(y %in% glottolog$iso, glottolog[tolower(glottolog$iso) %in% tolower(y),
+            ]$language, NA_character_)
     }, character(1))
 }
