@@ -1,8 +1,8 @@
 #' Create a map
 #'
-#' Map a set of linguoids and color them by feature or two sets of features.
+#' Map a set of languages and color them by feature or two sets of features.
 #'
-#' @param languages character vector of linguoids (can be written in lower case)
+#' @param languages character vector of languages (can be written in lower case)
 #' @param features character vector of features
 #' @param stroke.features additional independent stroke features
 #' @param popup character vector of strings that will appear in pop-up window
@@ -12,7 +12,7 @@
 #' @param label.position the position of labels: "left", "right", "top", "bottom"
 #' @param latitude numeric vector of latitudes
 #' @param longitude numeric vector of longitudes
-#' @param color vector of colors
+#' @param color vector of colors or palette. The color argument can be (1) a character vector of RGM or named colors; (2) the name of an RColorBrewer palette; (3) the full name of a viridis palette; (4) a function that receives a single value between 0 and 1 and returns a color. For more examples see \code{\link{colorNumeric}}
 #' @param stroke.color vector of stroke colors
 #' @param image.url character vector of URLs with an images
 #' @param image.width numeric vector of image widths
@@ -34,27 +34,23 @@
 #' @param stroke.opacity a numeric vector of stroke opacity.
 #' @param tile a character verctor with a map tiles, popularized by Google Maps. See \href{https://leaflet-extras.github.io/leaflet-providers/preview/index.html}{here} for the complete set.
 #' @param tile.name a character verctor with a user's map tiles' names
-#' @param scale.bar logical. If TRUE, function show scale-bar. By default is TRUE.
+#' @param scale.bar logical. If TRUE, function shows scale-bar. By default is TRUE.
 #' @param scale.bar.position the position of the scale-bar: "topright", "bottomright", "bottomleft","topleft"
-#' @param minimap = FALSE,
+#' @param minimap logical. If TRUE, function shows mini map. By default is FALSE.
 #' @param minimap.position the position of the minimap: "topright", "bottomright", "bottomleft","topleft"
 #' @param minimap.width The width of the minimap in pixels.
 #' @param minimap.height The height of the minimap in pixels.
 #' @param glottolog.source A character vector that define which glottolog database is used: "original" or "modified" (by default)
+#' @param map.orientation a character verctor with values "Pacific" and "Atlantic". It distinguishes Pacific-centered and Atlantic-centered maps. By default is "Pacific".
+#' @param zoom.control logical. If TRUE, function shows zoom controls. By default is FALSE.
 #' @author George Moroz <agricolamz@gmail.com>
 #' @examples
 #' map.feature(c("Adyghe", "Russian"))
 #'
-#' ## All Sign languages
-#' map.feature(lang.aff("Sign"))
-#'
 #' ## Map all Slavic languages
 #' map.feature(lang.aff(c("Slavic")))
 #'
-#' ## Add control buttons
-#' map.feature(c("Adyghe", "Russian"), control = TRUE)
-#'
-#' ## Color linguoids by feature
+#' ## Color languages by feature
 #' df <- data.frame(lang = c("Adyghe", "Kabardian", "Polish", "Russian", "Bulgarian"),
 #' feature = c("polysynthetic", "polysynthetic", "fusion", "fusion", "fusion"))
 #' map.feature(df$lang, df$feature)
@@ -73,19 +69,11 @@
 #' popup = c("Circassian", "Circassian", "Slavic", "Slavic", "Slavic"))
 #' map.feature(df$lang, df$feature, label = df$lang)
 #'
-#' ## Adding title
-#' df <- data.frame(lang = c("Adyghe", "Kabardian", "Polish", "Russian", "Bulgarian"),
-#' feature = c("polysynthetic", "polysynthetic", "fusion", "fusion", "fusion"),
-#' popup = c("Circassian", "Circassian", "Slavic", "Slavic", "Slavic"))
-#' map.feature(df$lang, df$feature, df$popup, title = "type of a language")
-#'
 #' ## Add your own coordinates
 #' map.feature("Adyghe", latitude = 43, longitude = 57)
 #'
 #' ## Change map tile
 #' map.feature("Adyghe", tile = "Thunderforest.OpenCycleMap")
-#' map.feature("Adyghe", tile = c("OpenStreetMap.BlackAndWhite", "Thunderforest.OpenCycleMap"))
-#' map.feature("Adyghe", tile = "Thunderforest.OpenCycleMap", tile.name = "colored")
 #'
 #' ## Add you own colors
 #' df <- data.frame(lang = c("Adyghe", "Kabardian", "Polish", "Russian", "Bulgarian"),
@@ -116,13 +104,14 @@
 #' ## Remove scale bar
 #' map.feature(c("Adyghe", "Russian"), scale.bar = FALSE)
 #'
+#'
 #' @export
 #' @import leaflet
 #' @importFrom stats complete.cases
 #' @importFrom grDevices gray
 #' @importFrom grDevices rainbow
 #' @importFrom rowr cbind.fill
-#' @import magrittr
+#' @importFrom magrittr %>%
 #'
 
 map.feature <- function(languages,
@@ -163,24 +152,27 @@ map.feature <- function(languages,
                         minimap.height = 150,
                         tile = "OpenStreetMap.Mapnik",
                         tile.name = NULL,
+                        zoom.control = FALSE,
+                        map.orientation = "Pacific",
                         glottolog.source = "modified"){
 
   ifelse(grepl(glottolog.source, "original"),
          glottolog <- lingtypology::glottolog.original,
          glottolog <- lingtypology::glottolog.modified)
+  if(typeof(languages) == "list"){languages <- unlist(languages)}
   if(sum(is.glottolog(languages, response = TRUE, glottolog.source = glottolog.source)) == 0){
     stop("There is no data to map")
-    }
+  }
 
-  # creat dataframe ---------------------------------------------------------
+  # create dataframe ---------------------------------------------------------
   mapfeat.df <- data.frame(languages, features,
                            popup = popup)
   if(sum(label == "") != length(label)){
     mapfeat.df$label <- label
-    }
+  }
 
   if (is.null(latitude) & is.null(longitude)) {  # if there are no latitude and longitude
-    mapfeat.df$long <- long.lang(languages, glottolog.source = glottolog.source)
+    mapfeat.df$long <- long.lang(languages, map.orientation = map.orientation, glottolog.source = glottolog.source)
     mapfeat.df$lat <- lat.lang(languages, glottolog.source = glottolog.source)
   } else {   # if there are latitude and longitude
     mapfeat.df$long <- longitude
@@ -190,8 +182,8 @@ map.feature <- function(languages,
   # remove any rows with NAs ------------------------------------------------
   mapfeat.df <- mapfeat.df[stats::complete.cases(mapfeat.df),]
 
-  # creat link --------------------------------------------------------------
-  mapfeat.df$link <- makelink(as.character(mapfeat.df$languages),
+  # create link --------------------------------------------------------------
+  mapfeat.df$link <- url.lang(as.character(mapfeat.df$languages),
                               popup = mapfeat.df$popup,
                               glottolog.source = glottolog.source)
 
@@ -208,17 +200,26 @@ map.feature <- function(languages,
   }
 
   # change feature names ----------------------------------------------------
-  levels(mapfeat.df$features) <- paste(names(table(mapfeat.df$features)), " (", table(mapfeat.df$features), ")", sep = "")
+  # levels(mapfeat.df$features) <- paste(names(table(mapfeat.df$features)), " (", table(mapfeat.df$features), ")", sep = "")
 
-  # create a pallet ---------------------------------------------------------
-  if (length(table(mapfeat.df$features)) <= 1){color <- "blue"}
+  # if features are numeric -------------------------------------------------
+
+
+  # create a palette ---------------------------------------------------------
+  if (length(table(mapfeat.df$features)) <= 1 & is.null(color)){color <- "blue"}
   if (is.null(color)) {
+    if(is.numeric(mapfeat.df$features)){
+      pal <- leaflet::colorNumeric(palette = "BuPu", domain = mapfeat.df$features)
+    } else {
+    set.seed(42)
     pal <- leaflet::colorFactor(sample(grDevices::rainbow(length(unique(mapfeat.df$features))), length(unique(mapfeat.df$features))),
                                 domain = mapfeat.df$features)
-  } else {
-    pal <- leaflet::colorFactor(color,
-                                domain = mapfeat.df$features)
-  }
+    }} else {
+      if(is.numeric(mapfeat.df$features)){
+        pal <- leaflet::colorNumeric(palette = color, domain = mapfeat.df$features)
+      }else {
+        pal <- leaflet::colorFactor(color, domain = mapfeat.df$features)
+      }}
 
   if(!is.null(stroke.features)){
     if (is.null(stroke.color)) {
@@ -246,7 +247,7 @@ map.feature <- function(languages,
   }
 
   ### create a map ------------------------------------------------------------
-  m <- leaflet::leaflet(mapfeat.df) %>%
+  m <- leaflet::leaflet(mapfeat.df, option=leafletOptions(zoomControl = zoom.control)) %>%
     leaflet::addTiles(tile[1]) %>%
     leaflet::addProviderTiles(tile[1], group = tile.name[1])
   if(length(tile) > 1){
@@ -261,7 +262,7 @@ map.feature <- function(languages,
                                          lat=mapfeat.df$lat,
                                          popup= mapfeat.df$link,
                                          label= mapfeat.df$label,
-                                         labelOptions = labelOptions(noHide = not(label.hide),
+                                         labelOptions = labelOptions(noHide = !(label.hide),
                                                                      direction = label.position,
                                                                      textOnly = TRUE,
                                                                      style = list("font-size" = paste0(label.fsize, "px"))),
@@ -292,7 +293,7 @@ map.feature <- function(languages,
                                 lat=mapfeat.stroke$lat,
                                 popup= mapfeat.df$link,
                                 label= mapfeat.df$label,
-                                labelOptions = labelOptions(noHide = not(label.hide),
+                                labelOptions = labelOptions(noHide = !(label.hide),
                                                             direction = label.position,
                                                             textOnly = TRUE,
                                                             style = list("font-size" = paste0(label.fsize, "px"))),
@@ -305,7 +306,7 @@ map.feature <- function(languages,
                                 lat=mapfeat.df$lat,
                                 popup= mapfeat.df$link,
                                 label= mapfeat.df$label,
-                                labelOptions = labelOptions(noHide = not(label.hide),
+                                labelOptions = labelOptions(noHide = !(label.hide),
                                                             direction = label.position,
                                                             textOnly = TRUE,
                                                             style = list("font-size" = paste0(label.fsize, "px"))),
@@ -321,7 +322,7 @@ map.feature <- function(languages,
                                          lat=mapfeat.df$lat,
                                          popup= mapfeat.df$link,
                                          label= mapfeat.df$label,
-                                         labelOptions = labelOptions(noHide = not(label.hide),
+                                         labelOptions = labelOptions(noHide = !(label.hide),
                                                                      direction = label.position,
                                                                      textOnly = TRUE,
                                                                      style = list("font-size" = paste0(label.fsize, "px"))),
@@ -345,7 +346,7 @@ map.feature <- function(languages,
                                      iconAnchorY = image.Y.shift))
   }
 
-  # map: tile and controll intaraction --------------------------------------
+  # map: tile and control interaction --------------------------------------
   if(length(tile) > 1){
     if (control == TRUE) {
       m <- m %>% leaflet::addLayersControl(
